@@ -8,8 +8,6 @@
 #include <stddef.h>
 #include <klibc/sysconfig.h>
 
-
-
 /*
  * This structure should be a power of two.  This becomes the
  * alignment unit.
@@ -17,9 +15,9 @@
 struct free_arena_header;
 
 struct arena_header {
-  size_t type;
-  size_t size;			/* Also gives the location of the next entry */
-  struct free_arena_header *next, *prev;
+	size_t type;
+	size_t size;		/* Also gives the location of the next entry */
+	struct free_arena_header *next, *prev;
 };
 
 #ifdef DEBUG_MALLOC
@@ -42,8 +40,13 @@ struct arena_header {
  * previous structure.
  */
 struct free_arena_header {
-  struct arena_header a;
-  struct free_arena_header *next_free, *prev_free;
+	struct arena_header a;
+	struct free_arena_header *next_free, *prev_free;
 };
 
 extern struct free_arena_header __malloc_head;
+
+/*
+ * Internal variable used by brk/sbrk
+ */
+extern char *__current_brk;
